==> jc-1.4.0.tar.gz: javax/net/ssl/SSLServerSocketFactory.h <==
// public abstract class javax.net.ssl.SSLServerSocketFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 832a3372b5f2d586 javax_net_ServerSocketFactory
// @dep_class be85d5901c8e527f javax_net_ssl_SSLServerSocketFactory

// header file dependencies
// @dep_header javax_net_ServerSocketFactory

#include "javax/net/ServerSocketFactory.h"

#ifndef _JC_javax_net_ssl_SSLServerSocketFactory_H_
#define _JC_javax_net_ssl_SSLServerSocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_net_ServerSocketFactory$object;
struct _jc_javax_net_ssl_SSLContext$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$sub_refs	_jc_javax_net_ssl_SSLServerSocketFactory$sub_refs;
typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$sub_nonrefs	_jc_javax_net_ssl_SSLServerSocketFactory$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$refs	_jc_javax_net_ssl_SSLServerSocketFactory$refs;
typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$nonrefs	_jc_javax_net_ssl_SSLServerSocketFactory$nonrefs;
typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$object	_jc_javax_net_ssl_SSLServerSocketFactory$object;

typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$fields_struct	_jc_javax_net_ssl_SSLServerSocketFactory$fields_struct;
typedef const struct _jc_javax_net_ssl_SSLServerSocketFactory$vmethods	_jc_javax_net_ssl_SSLServerSocketFactory$vmethods;
typedef const struct _jc_javax_net_ssl_SSLServerSocketFactory$vtable	_jc_javax_net_ssl_SSLServerSocketFactory$vtable;
typedef const struct _jc_javax_net_ssl_SSLServerSocketFactory$vtype	_jc_javax_net_ssl_SSLServerSocketFactory$vtype;

// Class fields structure
struct _jc_javax_net_ssl_SSLServerSocketFactory$fields_struct {
	struct _jc_javax_net_ssl_SSLContext$object	*context;
};
extern _jc_javax_net_ssl_SSLServerSocketFactory$fields_struct _jc_javax_net_ssl_SSLServerSocketFactory$class_fields;

// Constructors
extern void _jc_javax_net_ssl_SSLServerSocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_SSLServerSocketFactory$object *);

// Virtual methods
extern _jc_object_array *_jc_javax_net_ssl_SSLServerSocketFactory$method$getDefaultCipherSuites$09da17079d2c9bad(_jc_env *, struct _jc_javax_net_ssl_SSLServerSocketFactory$object *);
extern _jc_object_array *_jc_javax_net_ssl_SSLServerSocketFactory$method$getSupportedCipherSuites$f3b372cb435e53d6(_jc_env *, struct _jc_javax_net_ssl_SSLServerSocketFactory$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_SSLServerSocketFactory$method_info$getDefaultCipherSuites$09da17079d2c9bad;
extern _jc_method _jc_javax_net_ssl_SSLServerSocketFactory$method_info$getSupportedCipherSuites$f3b372cb435e53d6;

// Static methods
extern struct _jc_javax_net_ServerSocketFactory$object *_jc_javax_net_ssl_SSLServerSocketFactory$method$getDefault$56dc754ab2ffafa5(_jc_env *);

// Virtual methods structure
struct _jc_javax_net_ssl_SSLServerSocketFactory$vmethods {
	_jc_object_array	*(*getDefaultCipherSuites$09da17079d2c9bad)(_jc_env *, struct _jc_javax_net_ssl_SSLServerSocketFactory$object *);
	_jc_object_array	*(*getSupportedCipherSuites$f3b372cb435e53d6)(_jc_env *, struct _jc_javax_net_ssl_SSLServerSocketFactory$object *);
};

// Vtable
struct _jc_javax_net_ssl_SSLServerSocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ServerSocketFactory$vmethods	javax_net_ServerSocketFactory;
	_jc_javax_net_ssl_SSLServerSocketFactory$vmethods	javax_net_ssl_SSLServerSocketFactory;
};

// Vtype
struct _jc_javax_net_ssl_SSLServerSocketFactory$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLServerSocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLServerSocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLServerSocketFactory$refs {
    _jc_javax_net_ssl_SSLServerSocketFactory$sub_refs	javax_net_ssl_SSLServerSocketFactory;
    _jc_javax_net_ServerSocketFactory$sub_refs	javax_net_ServerSocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLServerSocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLServerSocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ServerSocketFactory$sub_nonrefs	javax_net_ServerSocketFactory;
    _jc_javax_net_ssl_SSLServerSocketFactory$sub_nonrefs	javax_net_ssl_SSLServerSocketFactory;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLServerSocketFactory$object {
	_jc_javax_net_ssl_SSLServerSocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLServerSocketFactory$vtype	*vtype;
	_jc_javax_net_ssl_SSLServerSocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLServerSocketFactory$vtype _jc_javax_net_ssl_SSLServerSocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLServerSocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLServerSocketFactory$class_object;

#endif	/* _JC_javax_net_ssl_SSLServerSocketFactory_H_ */

==> jc-1.4.6.tar.gz: javax/net/ssl/SSLServerSocketFactory.h <==
// public abstract class javax.net.ssl.SSLServerSocketFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 832a3372b5f2d586 javax_net_ServerSocketFactory
// @dep_class be85d5901c8e527f javax_net_ssl_SSLServerSocketFactory

// header file dependencies
// @dep_header javax_net_ServerSocketFactory

#include "javax/net/ServerSocketFactory.h"

#ifndef _JC_javax_net_ssl_SSLServerSocketFactory_H_
#define _JC_javax_net_ssl_SSLServerSocketFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_net_ServerSocketFactory$object;
struct _jc_javax_net_ssl_SSLContext$object;

// Typedefs
typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$sub_refs	_jc_javax_net_ssl_SSLServerSocketFactory$sub_refs;
typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$sub_nonrefs	_jc_javax_net_ssl_SSLServerSocketFactory$sub_nonrefs;
typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$refs	_jc_javax_net_ssl_SSLServerSocketFactory$refs;
typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$nonrefs	_jc_javax_net_ssl_SSLServerSocketFactory$nonrefs;
typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$object	_jc_javax_net_ssl_SSLServerSocketFactory$object;

typedef struct _jc_javax_net_ssl_SSLServerSocketFactory$fields_struct	_jc_javax_net_ssl_SSLServerSocketFactory$fields_struct;
typedef const struct _jc_javax_net_ssl_SSLServerSocketFactory$vmethods	_jc_javax_net_ssl_SSLServerSocketFactory$vmethods;
typedef const struct _jc_javax_net_ssl_SSLServerSocketFactory$vtable	_jc_javax_net_ssl_SSLServerSocketFactory$vtable;
typedef const struct _jc_javax_net_ssl_SSLServerSocketFactory$vtype	_jc_javax_net_ssl_SSLServerSocketFactory$vtype;

// Class fields structure
struct _jc_javax_net_ssl_SSLServerSocketFactory$fields_struct {
	struct _jc_javax_net_ssl_SSLContext$object	*context;
};
extern _jc_javax_net_ssl_SSLServerSocketFactory$fields_struct _jc_javax_net_ssl_SSLServerSocketFactory$class_fields;

// Constructors
extern void _jc_javax_net_ssl_SSLServerSocketFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_net_ssl_SSLServerSocketFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_javax_net_ssl_SSLServerSocketFactory$method$getDefaultCipherSuites$09da17079d2c9bad(_jc_env *, struct _jc_javax_net_ssl_SSLServerSocketFactory$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_net_ssl_SSLServerSocketFactory$method$getSupportedCipherSuites$f3b372cb435e53d6(_jc_env *, struct _jc_javax_net_ssl_SSLServerSocketFactory$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_net_ssl_SSLServerSocketFactory$method_info$getDefaultCipherSuites$09da17079d2c9bad;
extern _jc_method _jc_javax_net_ssl_SSLServerSocketFactory$method_info$getSupportedCipherSuites$f3b372cb435e53d6;

// Static methods
extern struct _jc_javax_net_ServerSocketFactory$object *_jc_javax_net_ssl_SSLServerSocketFactory$method$getDefault$56dc754ab2ffafa5(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_net_ssl_SSLServerSocketFactory$vmethods {
	_jc_object_array	*(*getDefaultCipherSuites$09da17079d2c9bad)(_jc_env *, struct _jc_javax_net_ssl_SSLServerSocketFactory$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getSupportedCipherSuites$f3b372cb435e53d6)(_jc_env *, struct _jc_javax_net_ssl_SSLServerSocketFactory$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_net_ssl_SSLServerSocketFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_net_ServerSocketFactory$vmethods	javax_net_ServerSocketFactory;
	_jc_javax_net_ssl_SSLServerSocketFactory$vmethods	javax_net_ssl_SSLServerSocketFactory;
};

// Vtype
struct _jc_javax_net_ssl_SSLServerSocketFactory$vtype {
	_jc_type			type;
	_jc_javax_net_ssl_SSLServerSocketFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLServerSocketFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_net_ssl_SSLServerSocketFactory$refs {
    _jc_javax_net_ssl_SSLServerSocketFactory$sub_refs	javax_net_ssl_SSLServerSocketFactory;
    _jc_javax_net_ServerSocketFactory$sub_refs	javax_net_ServerSocketFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_net_ssl_SSLServerSocketFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_net_ssl_SSLServerSocketFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_net_ServerSocketFactory$sub_nonrefs	javax_net_ServerSocketFactory;
    _jc_javax_net_ssl_SSLServerSocketFactory$sub_nonrefs	javax_net_ssl_SSLServerSocketFactory;
};

// Object instance structure
struct _jc_javax_net_ssl_SSLServerSocketFactory$object {
	_jc_javax_net_ssl_SSLServerSocketFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_net_ssl_SSLServerSocketFactory$vtype	*vtype;
	_jc_javax_net_ssl_SSLServerSocketFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_net_ssl_SSLServerSocketFactory$vtype _jc_javax_net_ssl_SSLServerSocketFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_net_ssl_SSLServerSocketFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_net_ssl_SSLServerSocketFactory$class_object;

#endif	/* _JC_javax_net_ssl_SSLServerSocketFactory_H_ */
